@@ -1,4 +1,4 @@
-/**
+/*
  * XML Security Library (http://www.aleksey.com/xmlsec).
  *
  * This is free software; see Copyright file in the source
@@ -67,7 +67,6 @@ extern "C" {
         (XMLSEC_X509DATA_CERTIFICATE_NODE | XMLSEC_X509DATA_CRL_NODE)
 
 XMLSEC_EXPORT int               xmlSecX509DataGetNodeContent    (xmlNodePtr node,
-                                                                 int deleteChildren,
                                                                  xmlSecKeyInfoCtxPtr keyInfoCtx);
 
 #ifdef __cplusplus
